#define LINUX_VERSION_CODE 199168
#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#define RHEL_MAJOR 7
#define RHEL_MINOR 9
#define RHEL_RELEASE_VERSION(a,b) (((a) << 8) + (b))
#define RHEL_RELEASE_CODE 1801
#define RHEL_RELEASE "1160.144.1"
#define KERNEL_HEADERS_CHECKSUM "d966ad1fd42f60c0b5fa8447887209a151945888"
